# ComSel

**ComSel** — это простая библиотека на Python, которая предоставляет графический интерфейс для выбора COM порта и скорости (Baudrate). Она использует библиотеку **DearPyGui** для построения пользовательского интерфейса и **pySerial** для работы с COM портами.

## Установка

Чтобы установить `comsel`, используйте `pip`:

```bash
pip install comsel
```

### Установка зависимостей

Если вы хотите установить библиотеку из исходников, убедитесь, что у вас установлены необходимые зависимости:

```bash
pip install -r requirements.txt
```

## Пример использования

```python
from comsel.port_select import select_com_port_and_baudrate

# Вызов функции выбора порта и скорости
port, baudrate = select_com_port_and_baudrate()

# Вывод результата
if port and baudrate:
    print(f"Selected COM port: {port}, Baudrate: {baudrate}")
else:
    print("Port or Baudrate not selected.")
```

### Описание

- **select_com_port_and_baudrate()**: Функция открывает окно для выбора COM порта и скорости, и возвращает выбранный порт и скорость.

## Возможности

- Автоматическое обнаружение доступных COM портов.
- Возможность ручного ввода COM порта и скорости.
- Проверка правильности введённых значений:
  - Порт должен быть в формате `COM1`, `COM2` и т.д.
  - Скорость должна быть в пределах от `1` до `1,000,000`.

## Визуальный интерфейс

`ComSel` использует **DearPyGui**, который обеспечивает простой и удобный графический интерфейс для выбора COM порта и скорости. Пример интерфейса:

- **Выбор COM порта**: Пользователь может выбрать порт из доступных или ввести его вручную.
- **Выбор скорости**: Пользователь может выбрать одну из популярных скоростей или ввести свою вручную.

## Технические требования

- **Python** версии 3.6 и выше.
- **pySerial**: Для работы с COM портами.
- **DearPyGui**: Для графического интерфейса.

### Установка зависимостей

```bash
pip install pyserial dearpygui
```

## Пример интерфейса

1. Окно для выбора COM порта:
   - Пользователь может выбрать из списка доступных портов или ввести COM порт вручную.
2. Окно для выбора скорости (Baudrate):
   - Пользователь может выбрать стандартные скорости или ввести свою.

## Лицензия

Этот проект распространяется под лицензией [MIT](LICENSE).

## Контакты

Если у вас возникли вопросы или предложения, свяжитесь с автором:

- **Автор**: Molisc
- **Email**: ivanrudko445@gmail.com
